pub struct TopicPermission { /* private fields */ }Expand description
Permissions per topic for the DataAccessToken.
Implementations
Sourceimpl TopicPermission
impl TopicPermission
Sourcepub fn new(
action: Action,
stream: impl Into<String>,
prefix: impl Into<String>,
topic_pattern: impl Into<String>,
) -> Self
pub fn new( action: Action, stream: impl Into<String>, prefix: impl Into<String>, topic_pattern: impl Into<String>, ) -> Self
Creates a new TopicPermission instance.
Arguments
resource- the resource to define what the client can access in terms of stream, prefix, topic, and type.action- the action to define what the client can do with the resource.
Returns
Returns a new TopicPermission instance.
Sourcepub fn full_qualified_topic_name(&self) -> String
pub fn full_qualified_topic_name(&self) -> String
Returns the full qualified topic name of resource.
Sourcepub fn topic_pattern(&self) -> &str
pub fn topic_pattern(&self) -> &str
topic pattern, e.g. +/+/+/something/#